==> jc-1.4.0.tar.gz: javax/crypto/spec/DHPublicKeySpec.h <==
// public class javax.crypto.spec.DHPublicKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dc5f27e085bd149f javax_crypto_spec_DHPublicKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHPublicKeySpec_H_
#define _JC_javax_crypto_spec_DHPublicKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_refs	_jc_javax_crypto_spec_DHPublicKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$refs	_jc_javax_crypto_spec_DHPublicKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$nonrefs	_jc_javax_crypto_spec_DHPublicKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$object	_jc_javax_crypto_spec_DHPublicKeySpec$object;

typedef const struct _jc_javax_crypto_spec_DHPublicKeySpec$vmethods	_jc_javax_crypto_spec_DHPublicKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHPublicKeySpec$vtable	_jc_javax_crypto_spec_DHPublicKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHPublicKeySpec$vtype	_jc_javax_crypto_spec_DHPublicKeySpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHPublicKeySpec$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPublicKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPublicKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPublicKeySpec$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHPublicKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_javax_crypto_spec_DHPublicKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_javax_crypto_spec_DHPublicKeySpec$method_info$getY$e067a5f1fb934d2a;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHPublicKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_DHPublicKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHPublicKeySpec$vmethods	javax_crypto_spec_DHPublicKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHPublicKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHPublicKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*g;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*y;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHPublicKeySpec$refs {
    _jc_javax_crypto_spec_DHPublicKeySpec$sub_refs	javax_crypto_spec_DHPublicKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHPublicKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs	javax_crypto_spec_DHPublicKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHPublicKeySpec$object {
	_jc_javax_crypto_spec_DHPublicKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHPublicKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHPublicKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHPublicKeySpec$vtype _jc_javax_crypto_spec_DHPublicKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHPublicKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHPublicKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHPublicKeySpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/DHPublicKeySpec.h <==
// public class javax.crypto.spec.DHPublicKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dc5f27e085bd149f javax_crypto_spec_DHPublicKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHPublicKeySpec_H_
#define _JC_javax_crypto_spec_DHPublicKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_refs	_jc_javax_crypto_spec_DHPublicKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$refs	_jc_javax_crypto_spec_DHPublicKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$nonrefs	_jc_javax_crypto_spec_DHPublicKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHPublicKeySpec$object	_jc_javax_crypto_spec_DHPublicKeySpec$object;

typedef const struct _jc_javax_crypto_spec_DHPublicKeySpec$vmethods	_jc_javax_crypto_spec_DHPublicKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHPublicKeySpec$vtable	_jc_javax_crypto_spec_DHPublicKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHPublicKeySpec$vtype	_jc_javax_crypto_spec_DHPublicKeySpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHPublicKeySpec$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPublicKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPublicKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPublicKeySpec$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHPublicKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_javax_crypto_spec_DHPublicKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_javax_crypto_spec_DHPublicKeySpec$method_info$getY$e067a5f1fb934d2a;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHPublicKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_javax_crypto_spec_DHPublicKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_DHPublicKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHPublicKeySpec$vmethods	javax_crypto_spec_DHPublicKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHPublicKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHPublicKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*g;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*y;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHPublicKeySpec$refs {
    _jc_javax_crypto_spec_DHPublicKeySpec$sub_refs	javax_crypto_spec_DHPublicKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHPublicKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHPublicKeySpec$sub_nonrefs	javax_crypto_spec_DHPublicKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHPublicKeySpec$object {
	_jc_javax_crypto_spec_DHPublicKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHPublicKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHPublicKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHPublicKeySpec$vtype _jc_javax_crypto_spec_DHPublicKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHPublicKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHPublicKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHPublicKeySpec_H_ */
